@@ -4,7 +4,7 @@
 # CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
 # See full LICENSE agreement in the root directory.
 # ======================================================================================
+from spectrochempy.utils.packages import generate_api
 
-from spectrochempy.utils import generate_api
-
-__all__ = generate_api(__file__)
+# in analysis package some classes are configurbles: list them!
+__all__, __configurables__ = generate_api(__file__, configurables=True)
