@@ -12,16 +12,15 @@ __all__ = ["MCRALS"]
 
 __dataset_methods__ = []
 
-import warnings
-
 import numpy as np
-from traitlets import Dict, HasTraits, Instance, Unicode
+from traitlets import Dict, HasTraits, Unicode
 
 from spectrochempy.analysis.pca import PCA
 from spectrochempy.core import INFO, info_, set_loglevel
 from spectrochempy.core.dataset.arraymixins.npy import dot
 from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.utils.exceptions import deprecated
+from spectrochempy.utils import exceptions
+from spectrochempy.utils.traits import NDDatasetType
 
 
 class MCRALS(HasTraits):
@@ -123,17 +122,26 @@ class MCRALS(HasTraits):
     getC : Callable
         An external function that will provide `len(hardConc)` concentration profiles:
         ```
-        getC(*args) -> hardC
+        getC(Ccurr, *argsGetC, **kwargsGetC) -> hardC
         ```
         or:
         ```
-        getC(*args) -> (hardC, out2, out3, ...)
+        getC(Ccurr, *argsGetC, **kwargsGetC) -> hardC, newArgsGetC
         ```
-        where *args are the parameters needed to completely specify the function. `harC` is a nadarray or NDDataset
-        of shape `(C.y, len(hardConc)`, and `out1`, `out2`, ... are supplementary outputs returned by the function.
+        or:
+        ```
+        getC(Ccurr, *argsGetCn, **kargsGetC) -> hardC, newArgsGetC, extOutput
+        ```
+        where Ccurr  is the current C martrix, *argsGetC are the parameters needed to completely specify the function. `hardC` is a nadarray or NDDataset
+        of shape `(C.y, len(hardConc)`, newArgsGetC are the updated parameters for the next iteration (can be None), and
+        extOutput can be any relevant output to be kept in extOutput attribute (only the last iteration extOutput is
+        kept)
 
-    argsGetC : tuple, optional
-        Extra arguments passed to the external function.
+    argsGetConc : tuple, optional
+        supplementary positional arguments passed to the external function.
+
+    kwargsGetConc: tuple, optional
+        supplementary keyword arguments passed to the external function
 
     hardC_to_C_idx : None or list or tuple, default None
         Indicates the correspondence between the indexes of the columns of hardC and of the C matrix. [1, None, 0]
@@ -185,16 +193,13 @@ class MCRALS(HasTraits):
     (NDDataset: [float64] unitless (shape: (y:4, x:96)), NDDataset: [float64] unitless (shape: (y:4, x:96)))
     """
 
-    _X = Instance(NDDataset)
-    _C = Instance(NDDataset, allow_none=True)
-    _fixedC = Instance(NDDataset, allow_none=True)
-    _extOutput = Instance(NDDataset, allow_none=True)
-    _St = Instance(NDDataset, allow_none=True)
-    _log = Unicode
+    _X = NDDatasetType()
+    _C = NDDatasetType(allow_none=True)
+    _St = NDDatasetType(allow_none=True)
+    _log = Unicode()
     _params = Dict()
 
     def __init__(self, dataset, guess, **kwargs):
-
         # list all default arguments:
 
         tol = kwargs.get("tol", 0.1)
@@ -206,15 +211,11 @@ class MCRALS(HasTraits):
         unimodConc = kwargs.get("unimodConc", "all")
         unimodConcTol = kwargs.get("unimodConcTol", 1.1)
         unimodConcMod = kwargs.get("unimodMod", "strict")
-        if "unimodTol" in kwargs.keys():
-            warnings.warn(
-                "unimodTol deprecated, use unimodConcTol instead", DeprecationWarning
-            )
+        if "unimodTol" in kwargs:
+            exceptions.deprecated("unimodTol", replace="unimodConcTol")
             unimodConcTol = kwargs.get("unimodTol", 1.1)
         if "unimodMod" in kwargs.keys():
-            warnings.warn(
-                "unimodMod deprecated, use unimodConcMod instead", DeprecationWarning
-            )
+            exceptions.deprecated("unimodMod", replace="unimodConcMod")
             unimodConcMod = kwargs.get("unimodConcMod", "strict")
 
         monoDecConc = kwargs.get("monoDecConc", None)
@@ -229,6 +230,7 @@ class MCRALS(HasTraits):
         hardConc = kwargs.get("hardConc", None)
         getConc = kwargs.get("getConc", None)
         argsGetConc = kwargs.get("argsGetConc", None)
+        kwargsGetConc = kwargs.get("kwargsGetConc", None)
         hardC_to_C_idx = kwargs.get("hardC_to_C_idx", "default")
 
         unimodSpec = kwargs.get("unimodSpec", None)
@@ -240,15 +242,13 @@ class MCRALS(HasTraits):
         normSpec = kwargs.get("normSpec", None)
 
         if "verbose" in kwargs.keys():
-            warnings.warn(
-                "verbose deprecated. Instead, use set_loglevel(INFO) before launching MCRALS",
-                DeprecationWarning,
+            exceptions.deprecated(
+                "verbose", replace="set_loglevel('INFO') before launching MCRALS"
             )
             set_loglevel(INFO)
 
         # Check initial data
-        # ------------------------------------------------------------------------
-
+        # ------------------------------------------------------------------------------
         initConc, initSpec = False, False
 
         if type(guess) is np.ndarray:
@@ -278,7 +278,6 @@ class MCRALS(HasTraits):
 
         # reset default text to indexes
         # ------------------------------
-
         if nonnegConc == "all":
             nonnegConc = np.arange(nspecies)
         elif nonnegConc is None:
@@ -340,8 +339,7 @@ class MCRALS(HasTraits):
             )
 
         # Compute initial spectra or concentrations   (first iteration...)
-        # ------------------------------------------------------------------------
-
+        # ------------------------------------------------------------------------------
         if initConc:
             if C.coordset is None:
                 C.set_coordset(y=X.y, x=C.x)
@@ -378,7 +376,6 @@ class MCRALS(HasTraits):
         info_(logentry)
 
         while change >= tol and niter < maxit and ndiv < maxdiv:
-
             C.data = np.linalg.lstsq(St.data.T, X.data.T, rcond=None)[0].T
             niter += 1
 
@@ -434,16 +431,29 @@ class MCRALS(HasTraits):
             # external concentration profiles
             # ------------------------------------------
             if hardConc is not None:
-                extOutput = getConc(*argsGetConc)
-                if isinstance(extOutput, dict):
-                    fixedC = extOutput["concentrations"]
-                    argsGetConc = extOutput["new_args"]
+                if kwargsGetConc is not None and argsGetConc is not None:
+                    output = getConc(C, *argsGetConc, **kwargsGetConc)
+                elif kwargsGetConc is None and argsGetConc is not None:
+                    output = getConc(C, *argsGetConc)
+                elif kwargsGetConc is not None and argsGetConc is None:
+                    output = getConc(C, **kwargsGetConc)
                 else:
-                    fixedC = extOutput
+                    output = getConc(C)
+
+                if isinstance(output, tuple):
+                    fixedC = output[0]
+                    argsGetConc = output[1]
+                    if len(output) == 3:
+                        extOutput = output[2]
+                    else:
+                        extOutput = None
+                else:
+                    fixedC = output
+                    extOutput = None
 
                 C.data[:, hardConc] = fixedC[:, hardC_to_C_idx]
 
-            # stores C in C_hard
+            # stores C in Chard
             Chard = C.copy()
 
             # compute St
@@ -553,10 +563,8 @@ class MCRALS(HasTraits):
 
         self._C = C
         if hardConc is not None:
-            self._fixedC = fixedC
             self._extOutput = extOutput
         else:
-            self._fixedC = None
             self._extOutput = None
 
         self._St = St
@@ -572,17 +580,10 @@ class MCRALS(HasTraits):
         """
         return self._X
 
-    @property
-    def fixedC(self):
-        """
-        The last concentration profiles including external profiles.
-        """
-        return self._fixedC
-
     @property
     def extOutput(self):
         """
-        The last output of the external function used to get.
+        The last output of the external function used to get concentrations.
         """
         return self._extOutput
 
@@ -629,7 +630,7 @@ class MCRALS(HasTraits):
         return self._log
 
     @property
-    @deprecated("Use log instead. This attribute may be removed in future version")
+    @exceptions.deprecated(replace="log")
     def logs(self):
         """
         Logs output.
