@@ -17,10 +17,10 @@ from time import time
 
 import numpy as np
 from numpy.linalg import norm
-from traitlets import Float, HasTraits, Instance, Int
+from traitlets import Float, HasTraits, Int
 
 from spectrochempy.core import INFO, debug_, get_loglevel, info_, set_loglevel
-from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.utils.traits import NDDatasetType
 
 
 class NNMF(HasTraits):
@@ -73,8 +73,8 @@ class NNMF(HasTraits):
     tol = Float()
     maxtime = Float()
     maxit = Int()
-    C = Instance(NDDataset)
-    St = Instance(NDDataset)
+    C = NDDatasetType()
+    St = NDDatasetType()
 
     def __init__(self, dataset, Ci, Sti, **kwargs):
         super().__init__()
@@ -150,12 +150,12 @@ class NNMF(HasTraits):
             gradW = gradW.T
 
             if iterW == 1:
-                tolW = 0.1 * tolW
+                tolW *= 0.1
 
             (H, gradH, iterH) = self.nlssubprob(V, W, H, tolH, 1000)
 
             if iterH == 1:
-                tolH = 0.1 * tolH
+                tolH *= 0.1
 
             if myiter % 10 == 0:
                 stdout.write(".")
@@ -213,12 +213,12 @@ class NNMF(HasTraits):
                 if suff_decr:
                     H = Hn
                     break
-                alpha = alpha * beta
+                alpha *= beta
             else:
                 if not suff_decr or (Hp == Hn).all():
                     H = Hp
                     break
-                alpha = alpha / beta
+                alpha /= beta
                 Hp = Hn
 
         if n_iter == maxiter:
