@@ -16,20 +16,19 @@ import numpy as np
 from matplotlib import pyplot as plt
 from matplotlib.ticker import MaxNLocator, ScalarFormatter
 from scipy import special
-from traitlets import HasTraits, Instance
+from traitlets import HasTraits
 
 from spectrochempy.analysis.svd import SVD
 from spectrochempy.core import info_
 from spectrochempy.core.dataset.arraymixins.npy import dot
 from spectrochempy.core.dataset.coord import Coord
-from spectrochempy.core.dataset.nddataset import NDDataset
 from spectrochempy.utils import NBlue, NRed
+from spectrochempy.utils.traits import NDDatasetType
 
-# ======================================================================================================================
+
+# ======================================================================================
 # class PCA
-# ======================================================================================================================
-
-
+# ======================================================================================
 class PCA(HasTraits):
     """
     Principal Component Analysis.
@@ -74,17 +73,17 @@ class PCA(HasTraits):
        Performs MCR-ALS of a |NDDataset| knowing the initial C or St matrix.
     """
 
-    _LT = Instance(NDDataset)
-    _S = Instance(NDDataset)
-    _X = Instance(NDDataset)
+    _LT = NDDatasetType()
+    _S = NDDatasetType()
+    _X = NDDatasetType()
 
-    _ev = Instance(NDDataset)
+    _ev = NDDatasetType()
     """|NDDataset| - Explained variances (The eigenvalues of the covariance matrix)."""
 
-    _ev_ratio = Instance(NDDataset)
+    _ev_ratio = NDDatasetType()
     """|NDDataset| - Explained variance per singular values."""
 
-    _ev_cum = Instance(NDDataset)
+    _ev_cum = NDDatasetType()
     """|NDDataset| - Cumulative Explained Variances."""
 
     def __init__(self, dataset, centered=True, standardized=False, scaled=False):
@@ -133,8 +132,7 @@ class PCA(HasTraits):
         VT = svd.VT
 
         # select n_pc loadings & compute scores
-        # --------------------------------------------------------------------
-
+        # ------------------------------------------------------------------------------
         # loadings
 
         LT = VT
@@ -162,7 +160,6 @@ class PCA(HasTraits):
 
         # other attributes
         # ----------------
-
         self._sv = svd.sv
         self._sv.x.title = "PC #"
 
@@ -177,14 +174,14 @@ class PCA(HasTraits):
 
         return
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Special methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def __str__(self, n_pc=5):
 
-        s = "\nPC\t\tEigenvalue\t\t%variance\t" "%cumulative\n"
-        s += "   \t\tof cov(X)\t\t per PC\t" "     variance\n"
+        s = "\n"
+        s += "PC\tEigenvalue\t\t%variance\t\t%cumulative\n"
+        s += "  \t of cov(X)\t\t   per PC\t\t   variance\n"
 
         n_pc = min(n_pc, len(self.ev.data))
         for i in range(n_pc):
@@ -194,14 +191,13 @@ class PCA(HasTraits):
                 self.ev_ratio.data[i],
                 self.ev_cum.data[i],
             )
-            s += "#{}  \t{:8.3e}\t\t {:6.3f}\t      {:6.3f}\n".format(*tup)
+            s += "#{}\t{:10.3e}\t\t{:9.3f}\t\t{:11.3f}\n".format(*tup)
 
         return s
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Private methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def _get_n_pc(self, n_pc=None):
 
         max_n_pc = self.ev.size
@@ -303,10 +299,9 @@ class PCA(HasTraits):
             ll[rank] = self._assess_dimension_(rank)
         return ll.argmax()
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Public methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def reduce(self, n_pc=None):
         """
         Apply a dimensionality reduction to the X dataset of shape [M, N].
@@ -333,7 +328,6 @@ class PCA(HasTraits):
 
         # scores (S) and loading (L^T) matrices
         # ------------------------------------
-
         S = self._S[:, :n_pc]
         LT = self._LT[:n_pc]
 
