@@ -14,21 +14,19 @@ __dataset_methods__ = []
 
 import warnings
 
-# ----------------------------------------------------------------------------
-# imports
-# ----------------------------------------------------------------------------
 import numpy as np
-from traitlets import HasTraits, Instance, Unicode
+from traitlets import HasTraits, Unicode
 
 from spectrochempy.core import INFO, info_, set_loglevel
 from spectrochempy.core.dataset.arraymixins.npy import dot
 from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.utils import exceptions
+from spectrochempy.utils.traits import NDDatasetType
 
-# ============================================================================
+
+# ======================================================================================
 # class SIMPLISMA
-# ============================================================================
-
-
+# ======================================================================================
 class SIMPLISMA(HasTraits):
     """
     SIMPLe to use Interactive Self-modeling Mixture Analysis.
@@ -58,20 +56,20 @@ class SIMPLISMA(HasTraits):
         15 - large offset).
     """
 
-    _St = Instance(NDDataset)
-    _C = Instance(NDDataset)
-    _X = Instance(NDDataset)
-    _Pt = Instance(NDDataset)
-    _s = Instance(NDDataset)
-    _logs = Unicode
+    _St = NDDatasetType()
+    _C = NDDatasetType()
+    _X = NDDatasetType()
+    _Pt = NDDatasetType()
+    _s = NDDatasetType()
+    _logs = Unicode()
 
     def __init__(self, dataset, **kwargs):
 
         super().__init__()
 
-        # ------------------------------------------------------------------------
+        # ------------------------------------------------------------------------------
         # Utility functions
-        # ------------------------------------------------------------------------
+        # ------------------------------------------------------------------------------
         def figures_of_merit(X, maxPIndex, C, St, j):
             # return %explained variance and stdev of residuals when the jth compound is added
             C[:, j] = X[:, maxPIndex[j]]
@@ -98,10 +96,9 @@ class SIMPLISMA(HasTraits):
             else:
                 return np.arange(X.shape[-1])
 
-        # ------------------------------------------------------------------------
+        # ------------------------------------------------------------------------------
         # Check data
-        # ------------------------------------------------------------------------
-
+        # ------------------------------------------------------------------------------
         X = dataset
 
         if len(X.shape) != 2:
@@ -112,9 +109,8 @@ class SIMPLISMA(HasTraits):
             # TODO: check whether negative values should be set to zero or not.
 
         if "verbose" in kwargs.keys():
-            warnings.warn(
-                "verbose deprecated. Instead, use set_loglevel(INFO) before launching MCRALS",
-                DeprecationWarning,
+            exceptions.deprecated(
+                "verbose", replace="use set_loglevel(INFO) before launching SIMPLISMA"
             )
             set_loglevel(INFO)
 
@@ -130,10 +126,9 @@ class SIMPLISMA(HasTraits):
         if interactive:
             n_pc = 100
 
-        # ------------------------------------------------------------------------
+        # ------------------------------------------------------------------------------
         # Core
-        # ------------------------------------------------------------------------
-
+        # ------------------------------------------------------------------------------
         if not interactive:
             logs = "*** Automatic SIMPL(I)SMA analysis *** \n"
         else:
