@@ -13,11 +13,12 @@ __all__ = ["SVD"]
 __dataset_methods__ = []
 
 import numpy as np
-from traitlets import HasTraits, Instance
+from traitlets import HasTraits
 
 from spectrochempy.core.dataset.basearrays.ndarray import MASKED
 from spectrochempy.core.dataset.coord import Coord
 from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.utils.traits import NDDatasetType
 
 
 def _svd_flip(U, VT, u_based_decision=True):
@@ -53,7 +54,7 @@ def _svd_flip(U, VT, u_based_decision=True):
     return U, VT
 
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 class SVD(HasTraits):
     """
     Performs a Singular Value Decomposition of a dataset.
@@ -93,13 +94,13 @@ class SVD(HasTraits):
     [   94.54    5.059 ... 8.687e-06 7.779e-06]
     """
 
-    U = Instance(NDDataset, allow_none=True)
+    U = NDDatasetType(allow_none=True)
     """|NDDataset| - Contains the left unitary matrix. Its shape depends on `full_matrices`"""
 
-    s = Instance(NDDataset)
+    s = NDDatasetType()
     """|NDDataset| - Vector of singular values"""
 
-    VT = Instance(NDDataset, allow_none=True)
+    VT = NDDatasetType(allow_none=True)
     """|NDDataset| - Contains a transpose matrix of the Loadings. Its shape depends on `full_matrices`"""
 
     def __init__(self, dataset, full_matrices=False, compute_uv=True):
@@ -110,7 +111,6 @@ class SVD(HasTraits):
 
         # check if we have the correct input
         # ----------------------------------
-
         X = dataset
 
         if isinstance(X, NDDataset):
@@ -131,7 +131,6 @@ class SVD(HasTraits):
 
         # Retains only valid rows and columns
         # -----------------------------------
-
         # unfortunately, the present SVD implementation in linalg library
         # doesn't support numpy masked arrays as input. So we will have to
         # remove the masked values ourselves
@@ -152,7 +151,6 @@ class SVD(HasTraits):
 
         # Performs the SVD
         # ----------------
-
         if data.size == 0 and np.product(data.shape[-2:]) == 0:
             raise np.linalg.LinAlgError(
                 "Arrays cannot be empty. You may " "want to check the masked data. "
@@ -166,7 +164,6 @@ class SVD(HasTraits):
 
         # Returns the diagonal sigma matrix as a NDDataset object
         # -------------------------------------------------------
-
         s = NDDataset(s)
         s.title = "singular values of " + X.name
         s.name = "sigma"
@@ -216,7 +213,6 @@ class SVD(HasTraits):
 
             # Returns the loadings (VT) as a NDDataset object
             # ------------------------------------------------
-
             VT = NDDataset(VT)
             VT.name = "V.T"
             VT.title = "loadings (V.t) of " + X.name
@@ -237,19 +233,17 @@ class SVD(HasTraits):
             self.U = None
             self.VT = None
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # special methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def __repr__(self):
         if self._compute_uv:
             return f"<svd: U{self.U.shape}, s({self.s.size}), VT{self.VT.shape}>"
         return f"<svd: s({self.s.size}), U, VT:not computed>"
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     #  Properties
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     @property
     def sv(self):
         """
@@ -301,6 +295,6 @@ class SVD(HasTraits):
         return ratio
 
 
-# ======================================================================================================================
+# ======================================================================================
 if __name__ == "__main__":
     pass
