@@ -22,10 +22,9 @@ from IPython import get_ipython
 
 from pathlib import Path
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 # Check the environment for plotting
-# ------------------------------------------------------------------
-
+# --------------------------------------------------------------------------------------
 # Do we run in IPython ?
 IN_IPYTHON = False
 KERNEL = None
@@ -83,9 +82,9 @@ if (
 
 ALL = ["NO_DISPLAY", "NO_DIALOG"]
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 # Now we can start loading the API
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 # import the core api
 from spectrochempy import core
 from spectrochempy.core import *  # noqa: F403, F401, E402
@@ -107,16 +106,16 @@ if IN_IPYTHON and KERNEL and not NO_DISPLAY:  # pragma: no cover
             and "--InlineBackend.rc={'figure.dpi': 96}" in sys.argv
         ):
             # We are running from NBSphinx - the plot must be inline to show up.
-            IP.magic("matplotlib inline")
+            IP.run_line_magic("matplotlib", "inline")
         else:
             if RUNNING_IN_COLAB:  # pragma: no cover
                 # allow using matplotlib widget
                 from google.colab import output
 
                 output.enable_custom_widget_manager()
-            IP.magic("matplotlib widget")  # widget
+            IP.run_line_magic("matplotlib", "widget")
     except Exception:
-        IP.magic("matplotlib qt")
+        IP.run_line_magic("matplotlib", "qt")
 
 # a useful utilities for dealing with path
 from spectrochempy.utils import pathclean
@@ -144,6 +143,6 @@ if NO_DISPLAY:
         DATADIR / "nmrdata" / "bruker" / "tests" / "nmr" / "topspin_2d"
     )
 
-# ==============================================================================
+# ======================================================================================
 if __name__ == "__main__":
     pass
