@@ -34,11 +34,10 @@ HAS_PLOTLY = go is not None
 
 # from spectrochempy.utils import deprecated
 
-# ======================================================================================================================
+
+# ======================================================================================
 # Management of the preferences for datasets
-# ======================================================================================================================
-
-
+# ======================================================================================
 class PreferencesSet(Meta):
     """
     Preferences setting.
@@ -68,7 +67,7 @@ class PreferencesSet(Meta):
                 res = super().__getitem__(key)
                 if res is None:
                     error_(
-                        f"not found {key}"
+                        KeyError, f"not found {key}"
                     )  # key = key.replace('_','.').replace('...', '_').replace('..',
                     # '-')  #  # res = mpl.rcParams[key]
 
@@ -98,15 +97,14 @@ class PreferencesSet(Meta):
                 setattr(plot_preferences, newkey, value)
                 self.parent[newkey] = value
             else:
-                error_(f"not found {key}")
+                error_(KeyError, f"not found {key}")
             return
 
         super().__setitem__(key, value)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Private methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def _get_alias(self, key):
 
         alias = []
@@ -142,10 +140,9 @@ class PreferencesSet(Meta):
 
         raise KeyError(f"{key} not found in matplolib preferences")
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Public methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def reset(self):
         """
         Remove the matplotlib_user json file to reset to defaults.
@@ -240,7 +237,8 @@ class PreferencesSet(Meta):
         """
         if stylename.startswith("scpy"):
             error_(
-                "Style name starting with `scpy` are READ-ONLY. Please use an another style name."
+                NameError,
+                "Style name starting with `scpy` are READ-ONLY. Please use an another style name.",
             )
             return
 
@@ -296,7 +294,7 @@ class PreferencesSet(Meta):
                 )
             if key == "savefig.bbox":
                 line = f"{key:40s} : standard\n"
-            txt += line.replace("#", "")
+            txt += line.replace("#", "").rstrip() + "\n"
 
         # Non matplotlib parameters,
         # some parameters are not saved in matplotlib style sheets so we willa dd them here
@@ -338,11 +336,9 @@ class PreferencesSet(Meta):
         return stylename
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Class NDPlot to handle plotting of datasets
-# ======================================================================================================================
-
-
+# ======================================================================================
 class NDPlot(HasTraits):
     """
     Plotting interface for |NDDataset|.
@@ -368,9 +364,9 @@ class NDPlot(HasTraits):
     # Metadata to store plot parameters
     _preferences = Instance(PreferencesSet, allow_none=True)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Generic plotter and plot related methods or properties
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     def plot(self, method=None, **kwargs):
         """
         Generic plot function.
@@ -434,8 +430,9 @@ class NDPlot(HasTraits):
             if _plotter is None:
                 # no plotter found
                 error_(
+                    NameError,
                     "The specified plotter for method "
-                    "`{}` was not found!".format(method)
+                    "`{}` was not found!".format(method),
                 )
                 raise IOError
         else:
@@ -443,13 +440,11 @@ class NDPlot(HasTraits):
 
         # Execute the plotter
         # --------------------
-
         return _plotter(**kwargs)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # plotter: plot_generic
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def _plot_generic(self, **kwargs):
 
         if self._squeeze_ndim == 1:
@@ -465,7 +460,7 @@ class NDPlot(HasTraits):
             ax = plot_3D(self, **kwargs)
 
         else:
-            error_("Cannot guess an adequate plotter, nothing done!")
+            error_(Exception, "Cannot guess an adequate plotter, nothing done!")
             return False
 
         return ax
@@ -477,10 +472,9 @@ class NDPlot(HasTraits):
         if self._fig is not None:
             plt.close(self._fig)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # setup figure properties
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def _figure_setup(self, ndim=1, method=None, **kwargs):
 
         prefs = self.preferences
@@ -492,7 +486,6 @@ class NDPlot(HasTraits):
 
         # Get current figure information
         # ------------------------------
-
         # should we use the previous figure?
         clear = kwargs.get("clear", True)
 
@@ -595,7 +588,6 @@ class NDPlot(HasTraits):
 
             # show projections (only useful for map or image)
             # ------------------------------------------------
-
             self.colorbar = colorbar = kwargs.get("colorbar", prefs.colorbar)
 
             proj = kwargs.get("proj", prefs.show_projections)
@@ -651,12 +643,10 @@ class NDPlot(HasTraits):
 
         return method
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # resume a figure plot
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def _plot_resume(self, origin, **kwargs):
-
         # put back the axes in the original dataset
         # (we have worked on a copy in plot)
         if not kwargs.get("data_transposed", False):
@@ -684,7 +674,6 @@ class NDPlot(HasTraits):
 
         # Additional matplotlib commands on the current plot
         # ---------------------------------------------------------------------
-
         commands = kwargs.get("commands", [])
         if commands:
             for command in commands:
@@ -716,14 +705,12 @@ class NDPlot(HasTraits):
     # ------------------------------------------------------------------------
     # Special attributes
     # ------------------------------------------------------------------------
-
     def __dir__(self):
         return ["fignum", "ndaxes", "divider"]
 
     # ------------------------------------------------------------------------
     # Properties
     # ------------------------------------------------------------------------
-
     @default("_preferences")
     def _preferences_default(self):
         # Reset all preferences
@@ -829,6 +816,6 @@ class NDPlot(HasTraits):
 
 plot = NDPlot.plot  # make plot accessible directly from the scp API
 
-# ======================================================================================================================
+# ======================================================================================
 if __name__ == "__main__":
     pass
