@@ -31,9 +31,8 @@ from traitlets import (
     default,
     validate,
 )
-from traittypes import Array
 
-from spectrochempy.core import error_, info_, print_
+from spectrochempy.core import error_, info_
 from spectrochempy.core.common.meta import Meta
 from spectrochempy.core.units import (
     DimensionalityError,
@@ -42,6 +41,7 @@ from spectrochempy.core.units import (
     set_nmr_context,
     ur,
 )
+from spectrochempy.extern.traittypes import Array
 from spectrochempy.utils import (
     INPLACE,
     MASKED,
@@ -49,7 +49,6 @@ from spectrochempy.utils import (
     TYPE_FLOAT,
     TYPE_INTEGER,
     MaskedConstant,
-    SpectroChemPyWarning,
     convert_to_html,
     insert_masked_print,
     is_number,
@@ -59,25 +58,21 @@ from spectrochempy.utils import (
     pathclean,
 )
 
-# ======================================================================================================================
+# ======================================================================================
 # Constants
-# ======================================================================================================================
-
+# ======================================================================================
 DEFAULT_DIM_NAME = list("xyzuvwpqrstijklmnoabcdefgh")[::-1]
 """Default dimension names."""
 
-# ======================================================================================================================
+# ======================================================================================
 # Printing settings
-# ======================================================================================================================
-
+# ======================================================================================
 numpyprintoptions()
 
 
-# ======================================================================================================================
+# ======================================================================================
 # The basic NDArray class
-# ======================================================================================================================
-
-
+# ======================================================================================
 class NDArray(HasTraits):
     """
     The basic |NDArray| object.
@@ -227,10 +222,9 @@ class NDArray(HasTraits):
 
         self.name = kwargs.pop("name", None)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Special methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def __copy__(self):
         return self.copy(deep=False)
 
@@ -378,8 +372,9 @@ class NDArray(HasTraits):
 
         if new.is_empty:
             error_(
+                IndexError,
                 f"Empty array of shape {new._data.shape} resulted from slicing.\n"
-                f"Check the indexes and make sure to use floats for location slicing"
+                f"Check the indexes and make sure to use floats for location slicing",
             )
             new = None
 
@@ -403,7 +398,7 @@ class NDArray(HasTraits):
     def __iter__(self):
         # iterate on the first dimension
         if self.ndim == 0:
-            error_("iteration over a 0-d array is not possible")
+            error_(ValueError, "iteration over a 0-d array is not possible")
             return None
 
         for n in range(len(self)):
@@ -454,17 +449,15 @@ class NDArray(HasTraits):
     def __str__(self):
         return repr(self)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Private methods and properties
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def _argsort(self, by=None, pos=None, descend=False):
         # found the indices sorted by values or labels
 
         if by is None:
             warnings.warn(
-                "parameter `by` should be set to `value` or `label`, use `value` by default",
-                SpectroChemPyWarning,
+                "parameter `by` should be set to `value` or `label`, use `value` by default"
             )
             by = "value"
 
@@ -473,9 +466,7 @@ class NDArray(HasTraits):
         elif "label" in by and not self.is_labeled:
             # by = 'value'
             # pos = None
-            warnings.warn(
-                "no label to sort, use `value` by default", SpectroChemPyWarning
-            )
+            warnings.warn("no label to sort, use `value` by default")
             args = np.argsort(self.data)
         elif "label" in by and self.is_labeled:
             labels = self._labels
@@ -540,7 +531,7 @@ class NDArray(HasTraits):
                 warnings.warn(
                     "the unnamed arguments are interpreted as `dims`. But a named argument `dims` or `axis`"
                     "(DEPRECATED) has been specified. \nThe unnamed arguments will thus be ignored.",
-                    SpectroChemPyWarning,
+                    UserWarning,
                 )
             dims = kdims
 
@@ -713,7 +704,7 @@ class NDArray(HasTraits):
                 # get the index of a given values
                 error = None
                 if np.all(loc > data.max()) or np.all(loc < data.min()):
-                    print_(
+                    info_(
                         f"This coordinate ({loc}) is outside the axis limits ({data.min()}-{data.max()}).\n"
                         f"The closest limit index is returned"
                     )
@@ -884,7 +875,7 @@ class NDArray(HasTraits):
 
                 dtype = self.dtype
                 data = ""
-                if self.implements("Coord") or self.implements("LinearCoord"):
+                if self._implements("Coord") or self._implements("LinearCoord"):
                     size = f" (size: {self.data.size})"
                 units = " " + self._repr_units()
             else:
@@ -1355,9 +1346,7 @@ class NDArray(HasTraits):
             return None
 
         if level > self.labels.ndim - 1:
-            warnings.warn(
-                "There is no such level in the existing labels", SpectroChemPyWarning
-            )
+            warnings.warn("There is no such level in the existing labels")
             return None
 
         if self.labels.ndim > 1:
@@ -1409,11 +1398,11 @@ class NDArray(HasTraits):
     def imag(self):
         return None
 
-    def implements(self, name=None):
+    def _implements(self, name=None):
         """
         Utility to check if the current object implements a given class.
 
-        Rather than isinstance(obj, <class>) use object.implements('<classname>').
+        Rather than isinstance(obj, <class>) use object._implements('<classname>').
         This is useful to check type without importing the module.
 
         Parameters
@@ -1425,11 +1414,11 @@ class NDArray(HasTraits):
         --------
         >>> from spectrochempy import NDArray
         >>> ar = NDArray([1., 2., 3.])
-        >>> ar.implements('NDDataset')
+        >>> ar._implements('NDDataset')
         False
-        >>> ar.implements('NDArray')
+        >>> ar._implements('NDArray')
         True
-        >>> ar.implements()
+        >>> ar._implements()
         'NDArray'
         """
         if name is None:
@@ -1610,8 +1599,7 @@ class NDArray(HasTraits):
 
         if self.ndim > 1:
             warnings.warn(
-                "We cannot set the labels for multidimentional data - Thus, these labels are ignored",
-                SpectroChemPyWarning,
+                "We cannot set the labels for multidimentional data - Thus, these labels are ignored"
             )
         else:
 
@@ -2130,7 +2118,7 @@ class NDArray(HasTraits):
             new._units = units
 
         else:
-            warnings.warn("There is no units for this NDArray!", SpectroChemPyWarning)
+            warnings.warn("There is no units for this NDArray!")
 
         if inplace:
             self._data = new._data
