@@ -25,9 +25,9 @@ from spectrochempy.core.units import Quantity, ur
 from spectrochempy.utils import INPLACE, NOMASK, colored_output, spacing_
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Coord
-# ======================================================================================================================
+# ======================================================================================
 class Coord(NDMath, NDArray):
     """
     Explicit coordinates for a dataset along a given axis.
@@ -144,9 +144,9 @@ class Coord(NDMath, NDArray):
     _size = Integer(0)
     _linear = Bool(False)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # initialization
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     def __init__(self, data=None, **kwargs):
 
         super().__init__(data=data, **kwargs)
@@ -160,10 +160,9 @@ class Coord(NDMath, NDArray):
         self._size = kwargs.pop("size", 0)
         # self._accuracy = kwargs.pop('accuracy', None)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # readonly property
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     @property
     def reversed(self):
         """bool - Whether the axis is reversed (readonly
@@ -203,12 +202,11 @@ class Coord(NDMath, NDArray):
         # this is in case default is called on a coord, while it is a coordset property
         return self
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # hidden properties (for the documentation, only - we remove the docstring)
     # some of the property of NDArray has to be hidden because they
     # are not useful for this Coord class
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     # NDarray methods
 
     @property
@@ -504,9 +502,9 @@ class Coord(NDMath, NDArray):
     def transpose(self, **kwargs):
         return self
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # public methods
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     def loc2index(self, loc):
         """
         Return the index corresponding to a given location.
@@ -530,10 +528,9 @@ class Coord(NDMath, NDArray):
         """
         return self._loc2index(loc)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # special methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     def __copy__(self):
         res = self.copy(deep=False)  # we keep name of the coordinate by default
         res.name = self.name
@@ -613,8 +610,9 @@ class Coord(NDMath, NDArray):
 
         if new.is_empty:
             error_(
+                IndexError,
                 f"Empty array of shape {new._data.shape} resulted from slicing.\n"
-                f"Check the indexes and make sure to use floats for location slicing"
+                f"Check the indexes and make sure to use floats for location slicing",
             )
             new = None
 
@@ -628,7 +626,7 @@ class Coord(NDMath, NDArray):
     def __setitem__(self, items, value):
 
         if self.linear:
-            error_("Linearly defined array are readonly")
+            error_(Exception, "Linearly defined array are readonly")
             return
 
         super().__setitem__(items, value)
@@ -677,10 +675,9 @@ class Coord(NDMath, NDArray):
         out = self._repr_value().rstrip()
         return out
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Private properties and methods
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     @traitdefault("_increment")
     def _increment_default(self):
         return 1.0
@@ -693,7 +690,7 @@ class Coord(NDMath, NDArray):
         self._linear = False  # to avoid action of the observer
 
         if self._squeeze_ndim > 1:
-            error_("Linearization is only implemented for 1D data")
+            error_(NotImplementedError, "Linearization is only implemented for 1D data")
             return
 
         data = self._data.squeeze()
@@ -806,7 +803,7 @@ class Coord(NDMath, NDArray):
         # if new._linear:
         #     # try to make it linear as well
         #     new._linearize()
-        #     if not new._linear and new.implements("LinearCoord"):
+        #     if not new._linear and new._implements("LinearCoord"):
         #         # can't be linearized -> Coord
         #         if inplace:
         #             raise Exception(
@@ -820,10 +817,9 @@ class Coord(NDMath, NDArray):
         #             new = Coord(new)
         return new
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Events
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     @observe(All)
     def _anytrait_changed(self, change):
         # ex: change {
@@ -955,7 +951,7 @@ class LinearCoord(Coord):
 
     _use_time = Bool(False)
     _show_datapoints = Bool(True)
-    _zpd = Integer
+    _zpd = Integer()
 
     def __init__(self, data=None, offset=0.0, increment=1.0, **kwargs):
 
@@ -1074,12 +1070,12 @@ class LinearCoord(Coord):
         self.meta.aser_frequency = val
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Set the operators
-# ======================================================================================================================
+# ======================================================================================
 _set_operators(Coord, priority=50)
 _set_operators(LinearCoord, priority=50)
 
-# ======================================================================================================================
+# ======================================================================================
 if __name__ == "__main__":
     pass
