@@ -29,29 +29,26 @@ from traitlets import (
     observe,
     validate,
 )
-from traittypes import Array
 
 from spectrochempy.core import error_, warning_
 from spectrochempy.core.dataset.arraymixins.ndio import NDIO
-from spectrochempy.core.dataset.arraymixins.ndmath import (  # _set_ufuncs,
-    NDMath,
-    _set_operators,
-)
+from spectrochempy.core.dataset.arraymixins.ndmath import NDMath  # _set_ufuncs,
+from spectrochempy.core.dataset.arraymixins.ndmath import _set_operators
 from spectrochempy.core.dataset.arraymixins.ndplot import NDPlot
 from spectrochempy.core.dataset.basearrays.ndarray import DEFAULT_DIM_NAME, NDArray
 from spectrochempy.core.dataset.basearrays.ndcomplex import NDComplexArray
 from spectrochempy.core.dataset.coord import Coord, LinearCoord
 from spectrochempy.core.dataset.coordset import CoordSet
 from spectrochempy.core.project.baseproject import AbstractProject
+from spectrochempy.extern.traittypes import Array
 from spectrochempy.utils import colored_output, get_user_and_node
 from spectrochempy.utils.exceptions import SpectroChemPyError, UnknownTimeZoneError
 from spectrochempy.utils.optional import import_optional_dependency
 
-# ======================================================================================================================
+
+# ======================================================================================
 # NDDataset class definition
-# ======================================================================================================================
-
-
+# ======================================================================================
 class NDDataset(NDMath, NDIO, NDPlot, NDComplexArray):
     """
     The main N-dimensional dataset class used by |scpy|.
@@ -241,9 +238,8 @@ class NDDataset(NDMath, NDIO, NDPlot, NDComplexArray):
     _origin = Unicode()
 
     # ----------------------------------------------------------------------------------
-    # initialisation
+    # Initialisation
     # ----------------------------------------------------------------------------------
-
     def __init__(
         self, data=None, coordset=None, coordunits=None, coordtitles=None, **kwargs
     ):
@@ -310,7 +306,6 @@ class NDDataset(NDMath, NDIO, NDPlot, NDComplexArray):
     # ----------------------------------------------------------------------------------
     # Special methods
     # ----------------------------------------------------------------------------------
-
     def __dir__(self):
         # Only these attributes are used for saving dataset
         # WARNING: be careful to keep the present order of the three first elements! Needed for save/load operations
@@ -542,7 +537,6 @@ class NDDataset(NDMath, NDIO, NDPlot, NDComplexArray):
     # ----------------------------------------------------------------------------------
     # Private methods and properties
     # ----------------------------------------------------------------------------------
-
     @default("_coordset")
     def __coordset_default(self):
         return None
@@ -744,7 +738,7 @@ class NDDataset(NDMath, NDIO, NDPlot, NDComplexArray):
                 # check the validity of the given coordinates in terms of size (if it correspond to one of the dims)
                 size = coord.size
 
-                if self.implements("NDDataset"):
+                if self._implements("NDDataset"):
                     idx = self._get_dims_index(coord.name)[0]  # idx in self.dims
                     if size != self._data.shape[idx]:
                         raise ValueError(
@@ -767,10 +761,9 @@ class NDDataset(NDMath, NDIO, NDPlot, NDComplexArray):
                 _dict[dim] = {"size": self.shape[index], "coord": getattr(self, dim)}
         return _dict
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # Public methods and property
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     # @property
     # def acquisition_date(self):
     #     """
@@ -1545,7 +1538,6 @@ class NDDataset(NDMath, NDIO, NDPlot, NDComplexArray):
 # ======================================================================================
 # module function
 # ======================================================================================
-
 # make some NDDataset operation accessible from the spectrochempy API
 thismodule = sys.modules[__name__]
 
@@ -1579,5 +1571,4 @@ for funcname in api_funcs:
 # ======================================================================================
 # Set the operators
 # ======================================================================================
-
 _set_operators(NDDataset, priority=100000)
