@@ -239,11 +239,9 @@ def plot_multiple(datasets, method="scatter", pen=True, labels=None, **kwargs):
     return ax
 
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 # plot_1D
-# ------------------------------------------------------------------
-
-
+# --------------------------------------------------------------------------------------
 @add_docstring(_PLOT1D_DOC)
 def plot_1D(dataset, method=None, **kwargs):
     """
@@ -277,8 +275,7 @@ def plot_1D(dataset, method=None, **kwargs):
     """
 
     # Get preferences
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     prefs = dataset.preferences
 
     # before going further, check if the style is passed in the parameters
@@ -291,7 +288,6 @@ def plot_1D(dataset, method=None, **kwargs):
 
     # Redirections ?
     # ------------------------------------------------------------------------
-
     # should we redirect the plotting to another method
     if dataset._squeeze_ndim > 1:
         return dataset.plot_2D(**kwargs)
@@ -306,7 +302,6 @@ def plot_1D(dataset, method=None, **kwargs):
 
     # Get the data to plot
     # ---------------------------------------------------------------
-
     new = dataset  # .copy()
     if new.size > 1:
         # don't apply to array of size one to preserve the x coordinate!!!!
@@ -342,7 +337,6 @@ def plot_1D(dataset, method=None, **kwargs):
 
     # Other ax properties that can be passed as arguments
     # ------------------------------------------------------------------------
-
     number_x_labels = prefs.number_of_x_labels
     number_y_labels = prefs.number_of_y_labels
     ax.xaxis.set_major_locator(MaxNLocator(number_x_labels))
@@ -365,15 +359,14 @@ def plot_1D(dataset, method=None, **kwargs):
 
     ax.grid(prefs.axes_grid)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # plot the dataset
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     # abscissa axis
     # the actual dimension name is the first in the new.dims list
     dimx = new.dims[-1]
     x = getattr(new, dimx)
-    if x is not None and x.implements("CoordSet"):
+    if x is not None and x._implements("CoordSet"):
         # if several coords, take the default ones:
         x = x.default
     xsize = new.size
@@ -481,10 +474,9 @@ def plot_1D(dataset, method=None, **kwargs):
         # set the line style if defined in the preferences or options
         line.set_marker(marker)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # axis
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     data_only = kwargs.get("data_only", False)
 
     if len(xdata) > 1:
@@ -551,7 +543,6 @@ def plot_1D(dataset, method=None, **kwargs):
     # ------------------------------------------------------------------------
     # labels
     # ------------------------------------------------------------------------
-
     # x label
 
     xlabel = kwargs.get("xlabel", None)
