@@ -69,11 +69,10 @@ reverse : `bool` or None [optional, default=None
 x_reverse : `bool` or None [optional, default=None
 """
 
-# ======================================================================================================================
+
+# ======================================================================================
 # nddataset plot2D functions
-# ======================================================================================================================
-
-
+# ======================================================================================
 @plot_method("2D", _PLOT2D_DOC)
 def plot_stack(dataset, **kwargs):
     """
@@ -131,8 +130,7 @@ def plot_2D(dataset, method=None, **kwargs):
     """
 
     # Get preferences
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     prefs = dataset.preferences
 
     # before going further, check if the style is passed in the parameters
@@ -144,8 +142,7 @@ def plot_2D(dataset, method=None, **kwargs):
     prefs.set_latex_font(prefs.font.family)  # reset latex settings
 
     # Redirections ?
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     # should we redirect the plotting to another method
     if dataset._squeeze_ndim < 2:
         return dataset.plot_1D(**kwargs)
@@ -162,7 +159,6 @@ def plot_2D(dataset, method=None, **kwargs):
 
     # Get the data to plot
     # ---------------------------------------------------------------
-
     # if we want to plot the transposed dataset
     transposed = kwargs.get("transposed", False)
     if transposed:
@@ -181,11 +177,10 @@ def plot_2D(dataset, method=None, **kwargs):
     method = new._figure_setup(ndim=2, method=method, **kwargs)
 
     ax = new.ndaxes["main"]
-    ax.name = ax.name + nameadd
+    ax.name += nameadd
 
     # Other properties that can be passed as arguments
     # ------------------------------------------------------------------------
-
     lw = kwargs.get("linewidth", kwargs.get("lw", prefs.lines_linewidth))
     alpha = kwargs.get("calpha", prefs.contour_alpha)
 
@@ -217,13 +212,11 @@ def plot_2D(dataset, method=None, **kwargs):
     # ------------------------------------------------------------------------
     # Set axis
     # ------------------------------------------------------------------------
-
     # set the abscissa axis
-    # ------------------------------------------------------------------------
     # the actual dimension name is the last in the new.dims list
     dimx = new.dims[-1]
     x = getattr(new, dimx)
-    if x is not None and x.implements("CoordSet"):
+    if x is not None and x._implements("CoordSet"):
         # if several coords, take the default ones:
         x = x.default
     xsize = new.shape[-1]
@@ -275,7 +268,7 @@ def plot_2D(dataset, method=None, **kwargs):
     # the actual dimension name is the second in the new.dims list
     dimy = new.dims[-2]
     y = getattr(new, dimy)
-    if y is not None and y.implements("CoordSet"):
+    if y is not None and y._implements("CoordSet"):
         # if several coords, take the default ones:
         y = y.default
     ysize = new.shape[-2]
@@ -317,7 +310,6 @@ def plot_2D(dataset, method=None, **kwargs):
 
     # z intensity (by default we plot real component of the data)
     # ------------------------------------------------------------------------
-
     if not kwargs.get("imag", False):
         zdata = new.real.masked_data
     else:
@@ -342,7 +334,6 @@ def plot_2D(dataset, method=None, **kwargs):
 
         # set the limits
         # ---------------
-
         if yscale == "log" and min(zlim) <= 0:
             # set the limits wrt smallest and largest strictly positive values
             ax.set_ylim(
@@ -455,9 +446,7 @@ def plot_2D(dataset, method=None, **kwargs):
 
         # stack plot
         # ----------
-
         # now plot the collection of lines
-        # --------------------------------
         # map colors using the colormap
 
         vmin, vmax = ylim
@@ -518,12 +507,10 @@ def plot_2D(dataset, method=None, **kwargs):
     elif kwargs.get("plottitle", False):
         ax.set_title(new.name)
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # labels
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     # x label
-    # ------------------------------------------------------------------------
     xlabel = kwargs.get("xlabel", None)
     if show_x_points:
         xlabel = "data points"
@@ -586,7 +573,7 @@ def plot_2D(dataset, method=None, **kwargs):
     if "colorbar" in new.ndaxes:
         if "surface" not in method and (not hasattr(new, "_axcb") or not new._axcb):
             axec = new.ndaxes["colorbar"]
-            axec.name = axec.name + nameadd
+            axec.name += nameadd
             new._axcb = mpl.colorbar.ColorbarBase(
                 axec, cmap=plt.get_cmap(cmap), norm=norm
             )
@@ -603,11 +590,9 @@ def plot_2D(dataset, method=None, **kwargs):
     return ax
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Waterfall
-# ======================================================================================================================
-
-
+# ======================================================================================
 def _plot_waterfall(ax, new, xdata, ydata, zdata, prefs, xlim, ylim, zlim, **kwargs):
     degazim = kwargs.get("azim", 10)
     degelev = kwargs.get("elev", 30)
@@ -747,7 +732,6 @@ def _plot_waterfall(ax, new, xdata, ydata, zdata, prefs, xlim, ylim, zlim, **kwa
     # ------------------------------------------------------------------------
     # labels
     # ------------------------------------------------------------------------
-
     # x label
     # ------------------------------------------------------------------------
     xlabel = kwargs.get("xlabel", None)
@@ -791,11 +775,9 @@ def _plot_waterfall(ax, new, xdata, ydata, zdata, prefs, xlim, ylim, zlim, **kwa
         ax.set_yticks([])
 
 
-# ======================================================================================================================
+# ======================================================================================
 # get clevels
-# ======================================================================================================================
-
-
+# ======================================================================================
 def _get_clevels(data, prefs, **kwargs):
     # Utility function to determine contours levels
 
