@@ -15,14 +15,14 @@ import matplotlib.pyplot as plt
 import numpy as np
 import scipy.interpolate
 from matplotlib.widgets import SpanSelector
-from traitlets import Float, HasTraits, Instance, Int, List, Tuple, Unicode
+from traitlets import Float, HasTraits, Int, List, Tuple, Unicode
 
 from spectrochempy.core import debug_, warning_
-from spectrochempy.core.dataset.nddataset import NDDataset
 from spectrochempy.core.plotters.multiplot import multiplot
 from spectrochempy.core.processors.smooth import smooth
 from spectrochempy.core.processors.utils import _units_agnostic_method
 from spectrochempy.utils import TYPE_FLOAT, TYPE_INTEGER, trim_ranges
+from spectrochempy.utils.traits import NDDatasetType
 
 
 class BaselineCorrection(HasTraits):
@@ -65,8 +65,8 @@ class BaselineCorrection(HasTraits):
         show()
     """
 
-    dataset = Instance(NDDataset)
-    corrected = Instance(NDDataset)
+    dataset = NDDatasetType()
+    corrected = NDDatasetType()
     method = Unicode("sequential")
     interpolation = Unicode("polynomial")
     axis = Int(-1)
@@ -205,6 +205,8 @@ class BaselineCorrection(HasTraits):
 
             s.append(sect)
 
+        from spectrochempy.core.dataset.nddataset import NDDataset
+
         sbase = NDDataset.concatenate(s, axis=-1)
         # TODO: probably we could use masked data instead of concatenating - could be faster
         xbase = sbase.coordset(dim)
@@ -401,7 +403,7 @@ class BaselineCorrection(HasTraits):
             minspan=5,
             button=[1],
             useblit=True,
-            rectprops=dict(alpha=0.5, facecolor="blue"),
+            props=dict(alpha=0.5, facecolor="blue"),
         )
 
         fig.canvas.draw()
@@ -476,9 +478,9 @@ def basc(dataset, *ranges, **kwargs):
     return blc.compute(*ranges, **kwargs)
 
 
-# ======================================================================================================================
+# ======================================================================================
 # abc # TODO: some work to perform on this
-# ======================================================================================================================
+# ======================================================================================
 def abc(dataset, dim=-1, **kwargs):
     """
     Automatic baseline correction.
@@ -633,9 +635,9 @@ def dc(dataset, **kwargs):
     return dataset
 
 
-# =======================================================================================================================
+# ======================================================================================
 # private functions
-# =======================================================================================================================
+# ======================================================================================
 def _basecor(data, **kwargs):
     mode = kwargs.pop("mode", "linear")
 
