@@ -4,7 +4,6 @@
 # CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
 # See full LICENSE agreement in the root directory.
 # ======================================================================================
-
 __all__ = ["concatenate", "stack"]
 
 __dataset_methods__ = __all__
@@ -16,7 +15,11 @@ import numpy as np
 
 from spectrochempy.core.dataset.basearrays.ndarray import DEFAULT_DIM_NAME
 from spectrochempy.core.dataset.coord import Coord
-from spectrochempy.utils import DimensionsCompatibilityError, UnitsCompatibilityError
+from spectrochempy.utils import (
+    DimensionsCompatibilityError,
+    UnitsCompatibilityError,
+    exceptions,
+)
 from spectrochempy.utils.orderedset import OrderedSet
 
 
@@ -80,7 +83,7 @@ def concatenate(*datasets, **kwargs):
 
     # check uise
     if "force_stack" in kwargs:
-        warn("force_stack not used anymore, use stack() instead", DeprecationWarning)
+        exceptions.deprecated("force_stack", replace="method stack()")
         return stack(datasets)
 
     # get a copy of input datasets in order that input data are not modified
@@ -114,7 +117,6 @@ def concatenate(*datasets, **kwargs):
 
     # concatenate or stack the data array + mask
     # --------------------------------------------
-
     sss = []
     for i, dataset in enumerate(datasets):
         d = dataset.masked_data
@@ -137,11 +139,11 @@ def concatenate(*datasets, **kwargs):
                 for ds in datasets:
                     labels.append(ds.coordset[dim].labels)
 
-            if coords[dim].implements() in ["Coord", "LinearCoord"]:
+            if coords[dim]._implements() in ["Coord", "LinearCoord"]:
                 coords[dim] = Coord(coords[dim], linear=False)
                 if labels != []:
                     coords[dim]._labels = np.concatenate(labels)
-            elif coords[dim].implements("CoordSet"):
+            elif coords[dim]._implements("CoordSet"):
                 if labels != []:
                     labels = np.array(labels)
                     for i, coord in enumerate(coords[dim]):
@@ -242,8 +244,6 @@ def stack(*datasets):
 
 # utility functions
 # --------------------
-
-
 def _get_copy(datasets):
     # get a copy of datasets from the input
     if isinstance(datasets, tuple):
