@@ -65,18 +65,18 @@ ALIAS = [
 ]
 
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 class Importer(HasTraits):
     # Private _Importer class
 
-    objtype = Type
-    datasets = List
-    files = Dict
-    default_key = Unicode
-    protocol = Unicode
+    objtype = Type()
+    datasets = List()
+    files = Dict()
+    default_key = Unicode()
+    protocol = Unicode()
 
-    protocols = Dict
-    filetypes = Dict
+    protocols = Dict()
+    filetypes = Dict()
 
     def __init__(self):
 
@@ -175,8 +175,8 @@ class Importer(HasTraits):
         args = list(args)
         if (
             args
-            and hasattr(args[0], "implements")
-            and args[0].implements() in ["NDDataset"]
+            and hasattr(args[0], "_implements")
+            and args[0]._implements() in ["NDDataset"]
         ):
             # the first arg is an instance of NDDataset
             object = args.pop(0)
@@ -282,9 +282,9 @@ def _importer_method(func):
     return func
 
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 # Generic Read function
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 def read(*paths, **kwargs):
     """
     Generic read method.
@@ -681,11 +681,9 @@ def _read_remote(*args, **kwargs):
         return read_method(dataset, dst, **kwargs)
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Private functions
-# ======================================================================================================================
-
-
+# ======================================================================================
 @_importer_method
 def _read_dir(*args, **kwargs):
     _, directory = args
@@ -697,9 +695,10 @@ def _read_dir(*args, **kwargs):
         if key:
             importer = Importer()
             nd = importer(files[key], **kwargs)
-            if not isinstance(nd, list):
-                nd = [nd]
-            datasets.extend(nd)
+            if nd is not None:
+                if not isinstance(nd, list):
+                    nd = [nd]
+                datasets.extend(nd)
     return datasets
 
 
@@ -741,6 +740,6 @@ def _read_(*args, **kwargs):
     #         raise NotImplementedError
 
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 if __name__ == "__main__":
     pass
