@@ -22,12 +22,11 @@ from spectrochempy.core.dataset.coord import LinearCoord
 from spectrochempy.core.readers.importer import Importer, _importer_method
 from spectrochempy.core.units import ur
 from spectrochempy.extern.nmrglue import read_fid, read_pdata
-from spectrochempy.utils.exceptions import deprecated
+from spectrochempy.utils import exceptions
 
-# ======================================================================================================================
+# ======================================================================================
 # Constants
-# ======================================================================================================================
-
+# ======================================================================================
 FnMODE = ["undefined", "QF", "QSEQ", "TPPI", "STATES", "STATES-TPPI", "ECHO-ANTIECHO"]
 AQ_mod = ["QF", "QSIM", "QSEQ", "DQD"]
 
@@ -490,9 +489,9 @@ nmr_valid_meta = [
     # ('ymin_p', ''),
 ]
 
-# ======================================================================================================================
+# ======================================================================================
 # Digital filter functions
-# ======================================================================================================================
+# ======================================================================================
 # Extracted from nmrglue.fileio.bruker.py (BSD License)
 
 # Table of points to frequency shift Bruker data to remove digital filter
@@ -695,9 +694,9 @@ def _remove_digital_filter(dic, data):
 #         return scal()
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Bruker topspin import function
-# ======================================================================================================================
+# ======================================================================================
 def read_topspin(*paths, **kwargs):
     """
     Open Bruker TOPSPIN (NMR) dataset.
@@ -774,10 +773,7 @@ def read_topspin(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
-@deprecated(
-    "read_bruker_nmr reading method is deprecated and may be removed in next versions "
-    "- use read_topspin instead"
-)
+@exceptions.deprecated(replace="read_topspin")
 def read_bruker_nmr(*args, **kwargs):
     return read_topspin(*args, **kwargs)
 
@@ -803,10 +799,9 @@ def _read_topspin(*args, **kwargs):
     # is-it a processed dataset (1r, 2rr ....
     processed = True if path.match("pdata/*/*") else False
 
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     # start reading ....
-    # ------------------------------------------------------------------------
-
+    # ----------------------------------------------------------------------------------
     parents = path.parents
 
     # Get data and acquisition parameters
