@@ -23,14 +23,15 @@ from traitlets import (
     observe,
 )
 
-from spectrochempy.utils import MetaConfigurable, get_pkg_path, pathclean
+from spectrochempy.utils import get_pkg_path, pathclean
+from spectrochempy.utils.traits import MetaConfigurable
 
 # from spectrochempy.core import warning_
 
 
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 # available matplotlib styles (equivalent of plt.style.available)
-# ------------------------------------------------------------------
+# --------------------------------------------------------------------------------------
 def available_styles():
     """
     All matplotlib `styles <https://matplotlib.org/users/style_sheets.html>`_
@@ -60,12 +61,12 @@ class PlotPreferences(MetaConfigurable):
     name = Unicode("PlotPreferences")
     description = Unicode("Options for Matplotlib")
     updated = Bool(False)
-    _groups = Set(Unicode)
-    _subgroups = Set(Unicode)
-    _members = Set(Unicode)
-    # ------------------------------------------------------------------------
+    _groups = Set(Unicode())
+    _subgroups = Set(Unicode())
+    _members = Set(Unicode())
+    # ----------------------------------------------------------------------------------
     # Configuration entries based on the classic matplotlib style
-    # ------------------------------------------------------------------------
+    # ----------------------------------------------------------------------------------
     #
     # LINES
     # See http://matplotlib.org/api/artist_api.html#module-matplotlib.lines for more
@@ -407,7 +408,7 @@ class PlotPreferences(MetaConfigurable):
         False, help=r"""When True, use mathtext for scientific notation."""
     ).tag(config=True, kind="")
     axes_formatter_useoffset = Bool(
-        True,
+        False,
         help=r"""If True, the tick label formatter will default to labeling ticks
                                     relative to an offset when the data range is small compared to the minimum
                                     absolute value of the data.""",
@@ -807,9 +808,9 @@ class PlotPreferences(MetaConfigurable):
                           randomly scaled.""",
     ).tag(config=True, kind="")
 
-    # ==================================================================================================================
+    # ==================================================================================
     # NON MATPLOTLIB OPTIONS
-    # ==================================================================================================================
+    # ==================================================================================
     style = Union(
         (Unicode(), List(), Tuple()), help="Basic matplotlib style to use"
     ).tag(config=True, default_="scpy")
@@ -880,7 +881,7 @@ class PlotPreferences(MetaConfigurable):
     )
 
     def __init__(self, **kwargs):
-        super().__init__(jsonfile="PlotPreferences", **kwargs)
+        super().__init__(section="PlotPreferences", **kwargs)
         for key in plt.rcParams:
             lis = key.split(".")
             if len(lis) > 1:
