@@ -28,7 +28,7 @@ __all__ = [
 
 
 def pstr(object, **kwargs):
-    if hasattr(object, "implements") and object.implements() in [
+    if hasattr(object, "_implements") and object._implements() in [
         "NDArray",
         "NDComplexArrray",
         "NDDataset",
@@ -41,11 +41,9 @@ def pstr(object, **kwargs):
         return str(object).strip()
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Terminal colors and styles
-# ======================================================================================================================
-
-
+# ======================================================================================
 def TBold(text):
     return Style.BRIGHT + str(text) + Style.RESET_ALL
 
@@ -195,14 +193,12 @@ def convert_to_html(obj):
     return html
 
 
-# ======================================================================================================================
+# ======================================================================================
 #  Printing options
 #  copied from numpy.ma.core to avoid using
 #  the non-public interface of numpy.ma
 #  see the header of numpy.ma.core.py for the license
-# ======================================================================================================================
-
-
+# ======================================================================================
 class _MaskedPrintOption(object):
 
     # """
@@ -360,11 +356,9 @@ def insert_masked_print(ds, mask_string="--"):
     return res
 
 
-# ======================================================================================================================
+# ======================================================================================
 # numpy printoptions
-# ======================================================================================================================
-
-
+# ======================================================================================
 def numpyprintoptions(
     precision=4,
     threshold=6,
